summaryrefslogtreecommitdiff
path: root/lib/quotearg.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/quotearg.h')
-rw-r--r--lib/quotearg.h30
1 files changed, 16 insertions, 14 deletions
diff --git a/lib/quotearg.h b/lib/quotearg.h
index 01cd899d2..92dcb0482 100644
--- a/lib/quotearg.h
+++ b/lib/quotearg.h
@@ -39,49 +39,51 @@ extern char const *const quoting_style_args[];
struct quoting_options;
#ifndef PARAMS
-# if defined PROTOTYPES || (defined __STDC__ && __STDC__)
+# if defined PROTOTYPES || defined __STDC__
# define PARAMS(Args) Args
# else
# define PARAMS(Args) ()
# endif
#endif
+/* The functions listed below set and use a hidden variable
+ that contains the default quoting style options. */
+
/* Allocate a new set of quoting options, with contents initially identical
- to O if O is not null, or to a default value if O is null.
+ to O if O is not null, or to the default if O is null.
It is the caller's responsibility to free the result. */
struct quoting_options *clone_quoting_options
PARAMS ((struct quoting_options *o));
-/* Get the value of O's quoting style. */
+/* Get the value of O's quoting style. If O is null, use the default. */
enum quoting_style get_quoting_style PARAMS ((struct quoting_options *o));
-/* In O, set the value of the quoting style to S. */
+/* In O (or in the default if O is null),
+ set the value of the quoting style to S. */
void set_quoting_style PARAMS ((struct quoting_options *o,
enum quoting_style s));
-/* In O, set the value of the quoting options for character C to I.
+/* In O (or in the default if O is null),
+ set the value of the quoting options for character C to I.
Return the old value. Currently, the only values defined for I are
0 (the default) and 1 (which means to quote the character even if
it would not otherwise be quoted). */
int set_char_quoting PARAMS ((struct quoting_options *o, char c, int i));
/* Place into buffer BUF (of size BUFSIZE) a quoted version of
argument ARG (of size ARGSIZE), using O to control quoting.
+ If O is null, use the default.
Terminate the output with a null character, and return the written
size of the output, not counting the terminating null.
- If BUFSIZE is too small to store the output string, return the
- value that would have been returned had BUFSIZE been large enough.
+ If BUFFERSIZE is too small to store the output string, return the
+ value that would have been returned had BUFFERSIZE been large enough.
If ARGSIZE is -1, use the string length of the argument for ARGSIZE. */
-size_t quotearg_buffer PARAMS ((char *buf, size_t bufsize,
+size_t quotearg_buffer PARAMS ((char *buffer, size_t buffersize,
char const *arg, size_t argsize,
struct quoting_options const *o));
-/* The quoting options used by the convenience functions listed below. */
-
-extern struct quoting_options quotearg_quoting_options;
-
/* Use storage slot N to return a quoted version of the string ARG.
- The variable quotearg_quoting_options specifies the quoting options.
+ Use the default quoting options.
The returned value points to static storage that can be
reused by the next call to this function with the same value of N.
N must be nonnegative. */
@@ -39,49 +39,51 @@ extern char const *const quoting_style_args[];
it would not otherwise be quoted). */
int set_char_quoting PARAMS ((struct quoting_options *o, char c, int i));
-/* Place into buffer BUF (of size BUFSIZE) a quoted version of
+/* Place into buffer BUFFER (of size BUFFERSIZE) a quoted version of
argument ARG (of size ARGSIZE), using O to control quoting.